@@ -1,4 +1,6 @@
 pub mod denom;
+pub mod fin;
 pub mod orca;
+pub mod precision;
 pub mod swapper;
 pub mod tax;
